==> toolmate-0.3.20-py3-none-any.whl: toolmate/docs/000_Home.md <==
# ToolMate AI Documentation

# Introduction

ToolMate AI is an ambitious project sparked by the pioneering work of [LetMeDoIt AI](https://github.com/eliranwong/letmedoit). It's designed with the primary objective of offering a comprehensive suite of AI solutions that mirror the capabilities of [LetMeDoIt AI](https://github.com/eliranwong/letmedoit). However, ToolMate AI is remarkably different in that all core features are completely free, and it doesn't require the use of an OpenAI key.

As with [LetMeDoIt AI](https://github.com/eliranwong/letmedoit), ToolMate AI is designed to be capable of engaging in intuitive conversations, executing codes, providing up-to-date information, and performing a wide range of tasks. It's designed to learn, adapt, and grow with the user, offering personalized experiences and interactions.

Our recent developments, for example, [the ability to run multiple tools in a single request](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Running%20Multiple%20Tools%20in%20One%20Go.md), demonstrate that ToolMate AI is far more capable than LetMeDoIt AI, while we still maintain backward compatibility with [LetMeDoIt AI](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/LetMeDoIt%20Mode.md).

# Background

[Beyond LetMeDoIt AI](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/LetMeDoIt%20Mode.md)

# Installation

[Install Python](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Install%20Python.md)

[Install ToolMate AI](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Install%20ToolMate.md)

# Get Started

[First Launch](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/First%20launch.md)

[Quick Guide](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Quick%20Guide.md)

[Examples](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Examples.md)

# Optional Setup

[Download More LLMs](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Download%20LLM%20in%20GGUF%20Format.md)

[Install ffmpeg](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Install%20ffmpeg.md)

[Install fabric](https://github.com/danielmiessler/fabric?tab=readme-ov-file#Installation)

[Install Ollama](https://ollama.com/download)

[Groq API Key](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Groq%20API%20Setup.md)

[OpenAI API Key](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/OpenAI%20API%20Setup.md)

[Google Cloud Service Credentials](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Google%20Cloud%20Service%20Credential%20Setup.md)

[GPU Acceleration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/GPU%20Acceleration.md)

[GPU Acceleration with Llama.cpp Server](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/GPU%20Acceleration%20with%20Llama_cpp%20server.md)

# Esssential

[Action Menu](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Action%20Menu.md)

[Change AI Backends and Models](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Change%20AI%20Backends%20and%20Models.md)

[Tool Selection Configurations](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Tool%20Selection%20Configurations.md)

[Risk Management Agent](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Risk%20Management%20Agent.md)

[Predefined Contexts](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Predefined%20Contexts.md)

# Distinctive Features

[Support Wide Range of Backends and Models](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Supported%20Backends%20and%20Models.md)

[Tool Calling for Any LLMs](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Function%20Call%20Approach%20with%20Any%20LLMs.md)

[Running Multiple Tools in One Go](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Running%20Multiple%20Tools%20in%20One%20Go.md)

[Deep Reflection Agents](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Deep%20Agents.md)

[Highly Customisable Plugins](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/000_Home.md#plugins)

[Integration with Popular AI Tools](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/000_Home.md#integration)

# Plugins

[Plugins ‐ Overview](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Overview.md)

[Plugins - How to Write a Custom Plugin](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20How%20to%20Write%20a%20Custom%20Plugin.md)

[Plugins ‐ Add Aliases](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Add%20Aliases.md)

[Plugins ‐ Input Suggestions](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Input%20Suggestions.md)

[Plugins ‐ Install Additional Packages](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Install%20Additional%20Packages.md)

[Plugins ‐ Predefined Contexts](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Predefined%20Contexts.md)

[Plugins ‐ Transform Text Output](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Transform%20Text%20Output.md)

[Plugins ‐ Work with LetMeDoIt AI Configurations](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Work%20with%20Configurations.md)

[Plugins ‐ Function Calling](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Function%20Calling.md)

[Plugins ‐ Run Codes with Specific Packages](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Use%20Specific%20Packages.md)

[Plugins ‐ Work with Non‐conversational Model](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Work%20with%20Non-conversational%20Models.md)

[Plugins ‐ Integrate Text‐to‐speech Feature](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Integrate%20Speech%20Features.md)

[Plugins ‐ Integrate Other Shared Utilities](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Integrate%20Shared%20Utilities.md)

# Integration

[System Command Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/System%20Command%20Integration.md)

[Fabric Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Fabric%20Integration.md)

[Whisper.cpp Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Whisper_cpp%20Integration)

[Perplexica Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Perplexica%20Integration.md)

# Backward Compatibility

[LetMeDoIt AI](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/LetMeDoIt%20Mode.md)

# Speech Features

## Speech Settings

[Perplexica Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Speech%20Settings.md)

## Offline Text-to-Speech

[Windows - wsay](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Offline%20TTS%20-%20Windows.md)

[macOS - say](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Offline%20TTS%20-%20macOS.md)

[Linux - piper](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Offline%20TTS%20-%20Linux.md)

# Customisation

[Customise via Action Menu Items](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Action%20Menu.md)

[Customise Assistant Name](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Customise%20Assistant%20Name.md)

[Tool Selection Configurations](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Tool%20Selection%20Configurations.md)

[Configure Ollama Server](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Configure%20Ollama%20Server.md)

[Edit config.py](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Edit%20Config%20Manually.md)

# Miscellaneous

[Miscellaneous Features](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Miscellaneous.md)

# More

We are still working on ToolMate AI, many features are built-on our previous project `LetMeDoIt AI`.  If you cannot find a right page here, you may take a look at LetMeDoIt AI wiki https://github.com/eliranwong/letmedoit/wiki

==> toolmate-0.3.22-py3-none-any.whl: toolmate/docs/000_Home.md <==
# ToolMate AI Documentation

# Introduction

ToolMate AI is an ambitious project sparked by the pioneering work of [LetMeDoIt AI](https://github.com/eliranwong/letmedoit). It's designed with the primary objective of offering a comprehensive suite of AI solutions that mirror the capabilities of [LetMeDoIt AI](https://github.com/eliranwong/letmedoit). However, ToolMate AI is remarkably different in that all core features are completely free, and it doesn't require the use of an OpenAI key.

As with [LetMeDoIt AI](https://github.com/eliranwong/letmedoit), ToolMate AI is designed to be capable of engaging in intuitive conversations, executing codes, providing up-to-date information, and performing a wide range of tasks. It's designed to learn, adapt, and grow with the user, offering personalized experiences and interactions.

Our recent developments, for example, [the ability to run multiple tools in a single request](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Running%20Multiple%20Tools%20in%20One%20Go.md), demonstrate that ToolMate AI is far more capable than LetMeDoIt AI, while we still maintain backward compatibility with [LetMeDoIt AI](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/LetMeDoIt%20Mode.md).

# Background

[Beyond LetMeDoIt AI](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/LetMeDoIt%20Mode.md)

# Installation

[Install Python](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Install%20Python.md)

[Install ToolMate AI](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Install%20ToolMate.md)

# Get Started

[First Launch](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/First%20launch.md)

[Quick Guide](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Quick%20Guide.md)

[Examples](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Examples.md)

# Optional Setup

[Download More LLMs](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Download%20LLM%20in%20GGUF%20Format.md)

[Install ffmpeg](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Install%20ffmpeg.md)

[Install fabric](https://github.com/danielmiessler/fabric?tab=readme-ov-file#Installation)

[Install Ollama](https://ollama.com/download)

[Groq API Key](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Groq%20API%20Setup.md)

[OpenAI API Key](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/OpenAI%20API%20Setup.md)

[Google Cloud Service Credentials](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Google%20Cloud%20Service%20Credential%20Setup.md)

[GPU Acceleration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/GPU%20Acceleration.md)

[GPU Acceleration with Llama.cpp Server](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/GPU%20Acceleration%20with%20Llama_cpp%20server.md)

# Esssential

[Action Menu](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Action%20Menu.md)

[Change AI Backends and Models](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Change%20AI%20Backends%20and%20Models.md)

[Tool Selection Configurations](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Tool%20Selection%20Configurations.md)

[Risk Management Agent](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Risk%20Management%20Agent.md)

[Predefined Contexts](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Predefined%20Contexts.md)

# Distinctive Features

[Support Wide Range of Backends and Models](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Supported%20Backends%20and%20Models.md)

[Tool Calling for Any LLMs](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Function%20Call%20Approach%20with%20Any%20LLMs.md)

[Running Multiple Tools in One Go](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Running%20Multiple%20Tools%20in%20One%20Go.md)

[Deep Reflection Agents](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Reflection%20Agents.md)

[Highly Customisable Plugins](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/000_Home.md#plugins)

[Integration with Popular AI Tools](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/000_Home.md#integration)

# Plugins

[Plugins ‐ Overview](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Overview.md)

[Plugins - How to Write a Custom Plugin](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20How%20to%20Write%20a%20Custom%20Plugin.md)

[Plugins ‐ Add Aliases](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Add%20Aliases.md)

[Plugins ‐ Input Suggestions](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Input%20Suggestions.md)

[Plugins ‐ Install Additional Packages](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Install%20Additional%20Packages.md)

[Plugins ‐ Predefined Contexts](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Predefined%20Contexts.md)

[Plugins ‐ Transform Text Output](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Transform%20Text%20Output.md)

[Plugins ‐ Work with LetMeDoIt AI Configurations](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Work%20with%20Configurations.md)

[Plugins ‐ Function Calling](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Function%20Calling.md)

[Plugins ‐ Run Codes with Specific Packages](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Use%20Specific%20Packages.md)

[Plugins ‐ Work with Non‐conversational Model](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Work%20with%20Non-conversational%20Models.md)

[Plugins ‐ Integrate Text‐to‐speech Feature](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Integrate%20Speech%20Features.md)

[Plugins ‐ Integrate Other Shared Utilities](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Plugins%20-%20Integrate%20Shared%20Utilities.md)

# Integration

[System Command Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/System%20Command%20Integration.md)

[Fabric Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Fabric%20Integration.md)

[Whisper.cpp Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Whisper_cpp%20Integration)

[Perplexica Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Perplexica%20Integration.md)

# Backward Compatibility

[LetMeDoIt AI](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/LetMeDoIt%20Mode.md)

# Speech Features

## Speech Settings

[Perplexica Integration](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Speech%20Settings.md)

## Offline Text-to-Speech

[Windows - wsay](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Offline%20TTS%20-%20Windows.md)

[macOS - say](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Offline%20TTS%20-%20macOS.md)

[Linux - piper](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Offline%20TTS%20-%20Linux.md)

# Customisation

[Customise via Action Menu Items](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Action%20Menu.md)

[Customise Assistant Name](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Customise%20Assistant%20Name.md)

[Tool Selection Configurations](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Tool%20Selection%20Configurations.md)

[Configure Ollama Server](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Configure%20Ollama%20Server.md)

[Edit config.py](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Edit%20Config%20Manually.md)

# Miscellaneous

[Miscellaneous Features](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Miscellaneous.md)

# More

We are still working on ToolMate AI, many features are built-on our previous project `LetMeDoIt AI`.  If you cannot find a right page here, you may take a look at LetMeDoIt AI wiki https://github.com/eliranwong/letmedoit/wiki
